pymia
=====

.. image:: https://readthedocs.org/projects/pymia/badge/?version=latest
   :target: http://pymia.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

pymia contains generic and modular code for medical image analysis (mia) with Python (py).
pymia aims at accelerating state-of-the-art research in medical image analysis using machine learning, especially deep learning.
In contrast to other frameworks, pymia focuses on flexibility regarding the deep learning backend and features mainly data loading, interfaces for fast prototyping, and reproducibility.
Founded, and actively developed and maintained, by Fabian Balsiger and Alain Jungo.
